@@ -107,7 +107,11 @@ typedef enum {
 
 typedef enum {
 	GCM_CALIBRATE_DEVICE_KIND_CRT,
-	GCM_CALIBRATE_DEVICE_KIND_LCD,
+	GCM_CALIBRATE_DEVICE_KIND_LCD_CCFL,
+	GCM_CALIBRATE_DEVICE_KIND_LCD_LED_WHITE,
+	GCM_CALIBRATE_DEVICE_KIND_LCD_LED_RGB,
+	GCM_CALIBRATE_DEVICE_KIND_LCD_LED_RGB_WIDE,
+	GCM_CALIBRATE_DEVICE_KIND_LCD_CCFL_WIDE,
 	GCM_CALIBRATE_DEVICE_KIND_PROJECTOR,
 	GCM_CALIBRATE_DEVICE_KIND_UNKNOWN
 } GcmCalibrateDisplayKind;
