@@ -338,3 +338,109 @@ cd_colorspace_to_localised_string (CdColorspace colorspace)
 	}
 	return NULL;
 }
+
+/**
+ * gcm_utils_get_pixel_format:
+ **/
+static CdPixelFormat
+gcm_utils_get_pixel_format (GdkPixbuf *pixbuf)
+{
+	guint bits;
+	CdPixelFormat format = CD_PIXEL_FORMAT_UNKNOWN;
+
+	/* no alpha channel */
+	bits = gdk_pixbuf_get_bits_per_sample (pixbuf);
+	if (!gdk_pixbuf_get_has_alpha (pixbuf) && bits == 8) {
+		format = CD_PIXEL_FORMAT_RGB24;
+		goto out;
+	}
+
+	/* alpha channel */
+	if (bits == 8) {
+		format = CD_PIXEL_FORMAT_RGBA32;
+		goto out;
+	}
+out:
+	return format;
+}
+
+/**
+ * gcm_utils_image_convert:
+ **/
+gboolean
+gcm_utils_image_convert (GtkImage *image,
+			 CdIcc *input,
+			 CdIcc *abstract,
+			 CdIcc *output,
+			 GError **error)
+{
+	CdPixelFormat pixel_format;
+	CdTransform *transform;
+	GdkPixbuf *pixbuf;
+	GdkPixbuf *original_pixbuf;
+	gboolean ret = TRUE;
+	guchar *data;
+	guint bpp;
+
+	/* get pixbuf */
+	pixbuf = gtk_image_get_pixbuf (image);
+	if (pixbuf == NULL)
+		goto out;
+
+	/* work out the pixel format */
+	pixel_format = gcm_utils_get_pixel_format (pixbuf);
+	if (pixel_format == CD_PIXEL_FORMAT_UNKNOWN) {
+		ret = FALSE;
+		g_set_error_literal (error, 1, 0, "format not supported");
+		goto out;
+	}
+
+	/* get a copy of the original image, *not* a ref */
+	original_pixbuf = g_object_get_data (G_OBJECT (pixbuf), "GcmImageOld");
+	if (original_pixbuf == NULL) {
+		data = g_memdup (gdk_pixbuf_get_pixels (pixbuf),
+				 gdk_pixbuf_get_bits_per_sample (pixbuf) *
+				 gdk_pixbuf_get_rowstride (pixbuf) *
+				 gdk_pixbuf_get_height (pixbuf) / 8);
+		original_pixbuf = gdk_pixbuf_new_from_data (data,
+			  gdk_pixbuf_get_colorspace (pixbuf),
+			  gdk_pixbuf_get_has_alpha (pixbuf),
+			  gdk_pixbuf_get_bits_per_sample (pixbuf),
+			  gdk_pixbuf_get_width (pixbuf),
+			  gdk_pixbuf_get_height (pixbuf),
+			  gdk_pixbuf_get_rowstride (pixbuf),
+			  (GdkPixbufDestroyNotify) g_free, NULL);
+		g_object_set_data_full (G_OBJECT (pixbuf), "GcmImageOld",
+					original_pixbuf,
+					(GDestroyNotify) g_object_unref);
+	}
+
+	/* convert in-place */
+	transform = cd_transform_new ();
+	cd_transform_set_input_icc (transform, input);
+	cd_transform_set_abstract_icc (transform, abstract);
+	cd_transform_set_output_icc (transform, output);
+	cd_transform_set_rendering_intent (transform, CD_RENDERING_INTENT_PERCEPTUAL);
+	cd_transform_set_input_pixel_format (transform, pixel_format);
+	cd_transform_set_output_pixel_format (transform, pixel_format);
+	bpp = gdk_pixbuf_get_rowstride (pixbuf) / gdk_pixbuf_get_width (pixbuf);
+	ret = cd_transform_process (transform,
+				    gdk_pixbuf_get_pixels (original_pixbuf),
+				    gdk_pixbuf_get_pixels (pixbuf),
+				    gdk_pixbuf_get_width (pixbuf),
+				    gdk_pixbuf_get_height (pixbuf),
+				    gdk_pixbuf_get_rowstride (pixbuf) / bpp,
+				    NULL,
+				    error);
+	if (!ret)
+		goto out;
+
+	/* refresh */
+	g_object_ref (pixbuf);
+	gtk_image_set_from_pixbuf (image, pixbuf);
+	g_object_unref (pixbuf);
+out:
+	if (transform != NULL)
+		g_object_unref (transform);
+	return ret;
+}
